/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2013 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#include "Device/Driver/Pataga.hpp"
#include "Device/Parser.hpp"
#include "Device/Driver.hpp"
#include "NMEA/Info.hpp"
#include "NMEA/InputLine.hpp"
#include "Units/System.hpp"


#include <stdlib.h>
#include <math.h>

class PatagaDevice : public AbstractDevice {
public:
  virtual bool ParseNMEA(const char *line, struct NMEAInfo &info) override;
};




/**
 * Parse a "$PTGA" sentence.
 *
 * Example: "$PTGA,2025,250,85,382*3D"
 */
static bool
PatagaParse(NMEAInputLine &line, NMEAInfo &info)
{
  fixed alt,vario,gr,bat;

  //  Baro Altitude QNE(1013.25)     2025     meter        2025 mt
  if (line.ReadChecked(alt))
    info.ProvidePressureAltitude(alt);

  //  Non compensated Vario  250      cm/sec       +2.50 m/s
  if (line.ReadChecked(vario))
    info.ProvideNoncompVario(vario/ 100.0f);

  //  Glide Ratio  85      ratio        8.5 : 1
  if (line.ReadChecked(gr)){
    info.ext_glideRatio = gr / 10.0f;
    info.ext_glideRatio_available.Update(info.clock);
  }

  // Battery Voltage   382      0.01 volts   3.82 volts
  if (line.ReadChecked(bat)) {
    info.ext_batteryVoltage = bat / 100.0f;
    info.ext_batteryVoltage_available.Update(info.clock);
  }

  return true;
}

bool
PatagaDevice::ParseNMEA(const char *_line, NMEAInfo &info)
{
  NMEAInputLine line(_line);
  char type[16];
  line.Read(type, 16);

  if (StringIsEqual(type, "$PTGA"))
    return PatagaParse(line, info);

  return false;
}

static Device *
PatagaCreateOnPort(const DeviceConfig &config, Port &com_port)
{
  return new PatagaDevice();
}

const struct DeviceRegister pataga_driver = {
  _T("Pataga"),
  _T("Pataga GPSVario"),
  0,
  PatagaCreateOnPort,
};
